using System.Collections.Generic;
using System.Linq;
using Microsoft.AspNetCore.Mvc;
using Restaurant.DataContext;
using Restaurant.Entities;
using Syncfusion.JavaScript;

namespace Restaurant.Controllers
{
    public class StockController : Controller
    {
        private readonly RestaurantDbContext _db;

        public StockController(RestaurantDbContext db)
        {
            _db = db;
        }

        public ActionResult Index()
        {
            var datasource = _db.Stocks.ToList();
            ViewBag.stockdatasource = datasource.ToList();

            var datasourcebrand = _db.Brands.ToList();
            var brandDropList = new List<object>();

            foreach (var brand in datasourcebrand)
                brandDropList.Add(new {value = brand.BrandName, text = brand.BrandName});

            ViewBag.brandlistdatasource = brandDropList; // Brand

            var datasourceproduct = _db.Products.ToList();
            var productDropList = new List<object>();

            foreach (var product in datasourceproduct)
                productDropList.Add(new {value = product.ProductName, text = product.ProductName});

            ViewBag.productlistdatasource = productDropList; // Product


            var datasourceratio = _db.Ratios.ToList();
            var ratioDropList = new List<object>();

            foreach (var ratio in datasourceratio)
                ratioDropList.Add(new {value = ratio.RatioName, text = ratio.RatioName});

            ViewBag.ratiolistdatasource = ratioDropList; // Ratio


            var datasourcecategory = _db.Catergories.ToList();
            var categoryDropList = new List<object>();

            foreach (var category in datasourcecategory)
                categoryDropList.Add(new {value = category.CategoryName, text = category.CategoryName});

            ViewBag.categorylistdatasource = categoryDropList; // Category


            var subdatasourcecategory = _db.SubCategories.ToList();
            var subcategoryDropList = new List<object>();

            foreach (var subcategory in subdatasourcecategory)
                subcategoryDropList.Add(new {value = subcategory.SubCategoryName, text = subcategory.SubCategoryName});

            ViewBag.subcategorylistdatasource = subcategoryDropList; // SubCategory


            var activedatasource = _db.Actives.ToList();
            var activeDropList = new List<object>();

            foreach (var active in activedatasource)
                activeDropList.Add(new {value = active.ActiveName, text = active.ActiveName});

            ViewBag.activelistdatasource = activeDropList; // Active


            return View();
        }

        public ActionResult Insert([FromBody] CRUDModel<Stock> value)
        {
            _db.Stocks.Add(value.Value);
            _db.SaveChanges();
            return Json(value.Value);
        }

        public ActionResult Update([FromBody] CRUDModel<Stock> value)
        {
            var stock = value.Value;
            var val = _db.Stocks.FirstOrDefault(rt => rt.StockId == stock.StockId);

            val.StockId = stock.StockId;
            val.RestaurantCode = stock.RestaurantCode;
            val.ProductName = stock.ProductName;
            val.Brand = stock.Brand;
            val.Category = stock.Category;
            val.SubCategory = stock.SubCategory;
            val.Active = stock.Active;
            val.PerchaseBulkUnit = stock.PerchaseBulkUnit;
            val.RecipeSellUnit = stock.RecipeSellUnit;
            val.Ratio = stock.Ratio;
            val.PurchasePrBulk = stock.PurchasePrBulk;
            val.BarcodeBulk = stock.BarcodeBulk;
            val.PurchasePrLastTransactionBulk = stock.PurchasePrLastTransactionBulk;
            val.PurchasePrSingle = stock.PurchasePrSingle;
            val.BarcodeSingle = stock.BarcodeSingle;
            val.PercentageMarkUp = stock.PercentageMarkUp;
            val.Profit = stock.Profit;
            val.SellPrice = stock.SellPrice;
            val.CostOfSales = stock.CostOfSales;
            val.Pos = stock.Pos;
            val.GlAccount = stock.GlAccount;
            val.PreferedSupplier = stock.PreferedSupplier;
            val.MinStockQty = stock.MinStockQty;
            val.StockCostValue = stock.StockCostValue;
            val.StockTakeName = stock.StockTakeName;
            val.ShelfOrder = stock.ShelfOrder;
            val.StockLocation = stock.StockLocation;
            val.StockBin = stock.StockBin;
            val.LastPurchaseVarianceAmount = stock.LastPurchaseVarianceAmount;
            val.LastPurchaseVariancePercentage = stock.LastPurchaseVariancePercentage;
            _db.Stocks.Update(val);
            _db.SaveChanges();
            return Json(value.Value);
        }

        public ActionResult Delete([FromBody] CRUDModel<Stock> value)
        {
            _db.Stocks.Remove(_db.Stocks.FirstOrDefault(st => st.StockId == int.Parse(value.Key.ToString())));
            _db.SaveChanges();
            return Json(value.Value);
        }
    }
}